@@ -6,9 +6,7 @@ Wrapper around the video content type.
 """
 import typing as t
 
-from ..signal_type import raw_text, trend_query, url, md5, video_tmk_pdqf
-from ..signal_type.signal_base import SignalType
-from .content_base import ContentType
+from threatexchange.content_type.content_base import ContentType
 
 
 class VideoContent(ContentType):
@@ -20,7 +18,3 @@ class VideoContent(ContentType):
     * avi
     * gif animations
     """
-
-    @classmethod
-    def get_signal_types(cls) -> t.List[t.Type[SignalType]]:
-        return [md5.VideoMD5Signal, video_tmk_pdqf.VideoTmkPdqfSignal]
